##################################################################
# THIS IS THE AUTO-GENERATED CODE. DON'T EDIT IT BY HANDS!
# Copyright (C) 2023 Ilya (Marshal) <https://github.com/MarshalX>.
# This file is part of Python atproto SDK. Licenced under MIT.
##################################################################


from typing_extensions import Literal

ReasonType = Literal['ReasonSpam', 'ReasonViolation', 'ReasonMisleading', 'ReasonSexual', 'ReasonRude', 'ReasonOther']

ReasonSpam: Literal['reasonSpam'] = 'reasonSpam'

ReasonViolation: Literal['reasonViolation'] = 'reasonViolation'

ReasonMisleading: Literal['reasonMisleading'] = 'reasonMisleading'

ReasonSexual: Literal['reasonSexual'] = 'reasonSexual'

ReasonRude: Literal['reasonRude'] = 'reasonRude'

ReasonOther: Literal['reasonOther'] = 'reasonOther'
