from atproto.xrpc_client.client.base import AsyncClientBase
from atproto.xrpc_client.namespaces import async_ns

# TODO(MarshalX): This file should be autogenerated!


class AsyncClientRaw(AsyncClientBase):
    """Group all root namespaces"""

    com: async_ns.ComNamespace
    bsky: async_ns.BskyNamespace

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

        self.com = async_ns.ComNamespace(self)
        self.bsky = async_ns.BskyNamespace(self)
